nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Casper

Struct Casper 

pub struct Casper { /* private fields */ }
CASPER

Implementations

Source

impl Casper

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn ctrl0(self) -> Reg<Ctrl0, RW>

Contains the offsets of AB and CD in the RAM.

pub const fn ctrl1(self) -> Reg<Ctrl1, RW>

Contains the opcode mode, iteration count, and result offset (in RAM) and also launches the accelerator. Note: with CP version: CTRL0 and CRTL1 can be written in one go with MCRR.

pub const fn loader(self) -> Reg<Loader, RW>

Contains an optional loader to load into CTRL0/1 in steps to perform a set of operations.

pub const fn status(self) -> Reg<Status, RW>

Indicates operational status and would contain the carry bit if used.

pub const fn intenset(self) -> Reg<Intenset, RW>

Sets interrupts

pub const fn intenclr(self) -> Reg<Intenclr, RW>

Clears interrupts

pub const fn intstat(self) -> Reg<Intstat, RW>

Interrupt status bits (mask of INTENSET and STATUS)

pub const fn areg(self) -> Reg<Areg, RW>

A register

pub const fn breg(self) -> Reg<Breg, RW>

B register

pub const fn creg(self) -> Reg<Creg, RW>

C register

pub const fn dreg(self) -> Reg<Dreg, RW>

D register

pub const fn res0(self) -> Reg<Res0, RW>

Result register 0

pub const fn res1(self) -> Reg<Res1, RW>

Result register 1

pub const fn res2(self) -> Reg<Res2, RW>

Result register 2

pub const fn res3(self) -> Reg<Res3, RW>

Result register 3

pub const fn mask(self) -> Reg<Mask, RW>

Optional mask register

pub const fn remask(self) -> Reg<Remask, RW>

Optional re-mask register

pub const fn lock(self) -> Reg<Lock, RW>

Security lock register